@@ -1,4 +1,4 @@
-## ---- echo = FALSE, output = "asis", comment = "", message = FALSE------------
+## ----echo = FALSE, output = "asis", comment = "", message = FALSE-------------
 library(magrittr)
 rev <- paste0("v", packageVersion("precommit"))
 cat(glue::glue("
@@ -6,11 +6,11 @@ repos:
 -   repo: https://github.com/lorenzwalthert/precommit
     rev: {rev}
     hooks:
-    -   id: style-files
-        args: [--style_pkg=styler, --style_fun=tidyverse_style]
+    -   id: lintr
+        args: [--warn_only, --key=value]
 "))
 
-## ---- echo = FALSE, comment = ""----------------------------------------------
+## ----echo = FALSE, comment = ""-----------------------------------------------
 readLines(system.file("pre-commit-hooks.yaml", package = "precommit")) %>%
   gsub("^ *exclude *: *>", "    exclude: |", .) %>%
   yaml::yaml.load() %>%
